﻿using Hotline.BatchTask;
using Quartz;
using Hotline.Share.Enums.BatchTask;
using Hotline.Share.Dtos.Order;
using Microsoft.Extensions.DependencyInjection;

namespace Hotline.Application.Jobs
{
    public class ApptaskJob : IJob, IDisposable
    {
        private readonly IApptaskDomainService _apptaskDomainService;
        private readonly IServiceProvider _serviceProvider;

        public ApptaskJob(IApptaskDomainService apptaskDomainService,
            IServiceProvider serviceProvider)
        {
            _apptaskDomainService = apptaskDomainService;
            _serviceProvider = serviceProvider;
        }

        public async Task Execute(IJobExecutionContext context)
        {
            var task = await _apptaskDomainService.GetWaitingTaskAsync(context.CancellationToken);
            if (task is null) return;
            IApptaskExecutor executor;
            switch (task.TaskType)
            {
                case ETaskType.Delay:
                    executor = _serviceProvider.GetService<IApptaskExecutor<BatchDelayNextFlowDto>>();
                    break;
                case ETaskType.Screen:
                    break;
                case ETaskType.VoiceVisit:
                    executor = _serviceProvider.GetService<IApptaskExecutor<BatchVoiceVisitDto>>();
                    break;
                default:
                    throw new ArgumentOutOfRangeException();
            }
            await _apptaskDomainService.ExecuteAsync(executor, task, context.CancellationToken);

        }

        /// <summary>Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.</summary>
        public void Dispose()
        {
            GC.SuppressFinalize(this);
        }


    }
}
